
## Installing

For a clean python installation (specially on MacOs) we recommend [using conda](docs/conda.md)

### Troubleshooting

On MacOs, also upgrade the build library:

```sh
python3 -m pip install --upgrade build
```
